if __name__ == '__main__':
    import xarray as xr
    import argparse

    parser = argparse.ArgumentParser(description="Format an AMF table to match EC's specifications")
    parser.add_argument('source', type=str, help='path to the existing USASK AMF table')
    parser.add_argument('destination', type=str, help='path to the location the table will be saved to')
    parser.add_argument('--complete', action='store_true', help='require a complete table when set')
    args = vars(parser.parse_args())

    usask = xr.open_dataset(args['source'])
    name_dict = {
        'clear_box_amf': 'clear_amf',
        'cloudy_box_amf': 'cloud_amf',
        'box_altitude': 'z',
        'surface_albedo': 'alb',
        'surface_pressure': 'p_surf',
        'cloud_top_pressure': 'p_cloud',
        'cloud_albedo': 'alb_cloud',
        'solar_zenith': 'sza',
        'viewing_zenith': 'vza',
        'azimuth_difference': 'daz'
    }
    ec = usask.rename(name_dict)
    remove = [v for v in ec.variables if v not in name_dict.values()]
    for name in remove:
        del ec[name]
    ec = ec.squeeze()
    ec = ec.transpose('alb', 'p_cloud', 'p_surf', 'sza', 'daz', 'vza', 'z')
    ec.to_netcdf(args['destination'])
    print(ec)
